@@ -27,10 +27,14 @@ import (
 var (
 	validComponents = sets.NewString(
 		"controller",
+		"contour-ingress-controller",
 		"hpaautoscaler",
 		"certcontroller",
 		"istiocontroller",
-		"nscontroller")
+		"net-http01",
+		"nscontroller",
+		"webhook",
+	)
 )
 
 // ValidateConfig enriches the leader election config validation
@@ -41,7 +45,7 @@ func ValidateConfig(configMap *corev1.ConfigMap) (*kle.Config, error) {
 		return nil, err
 	}
 
-	for _, component := range config.EnabledComponents.List() {
+	for component := range config.EnabledComponents {
 		if !validComponents.Has(component) {
 			return nil, fmt.Errorf("invalid enabledComponent %q: valid values are %q", component, validComponents.List())
 		}
