@@ -25,6 +25,9 @@
 # in a net-negative contributor experience.
 export DISABLE_MD_LINTING=1
 
+export GO111MODULE=on
+export GOFLAGS=-mod=vendor
+
 source $(dirname $0)/../vendor/knative.dev/test-infra/scripts/presubmit-tests.sh
 
 # We use the default build, unit and integration test runners.
